# coding: utf-8

# flake8: noqa

"""
    Machine Catalogue

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# import apis into sdk package
from inductiva.machines_catalogue_client.api.compute_api import ComputeApi
from inductiva.machines_catalogue_client.api.metrics_api import MetricsApi
from inductiva.machines_catalogue_client.api.pricing_api import PricingApi
from inductiva.machines_catalogue_client.api.simulators_api import SimulatorsApi

# import ApiClient
from inductiva.machines_catalogue_client.api_response import ApiResponse
from inductiva.machines_catalogue_client.api_client import ApiClient
from inductiva.machines_catalogue_client.configuration import Configuration
from inductiva.machines_catalogue_client.exceptions import OpenApiException
from inductiva.machines_catalogue_client.exceptions import ApiTypeError
from inductiva.machines_catalogue_client.exceptions import ApiValueError
from inductiva.machines_catalogue_client.exceptions import ApiKeyError
from inductiva.machines_catalogue_client.exceptions import ApiAttributeError
from inductiva.machines_catalogue_client.exceptions import ApiException

# import models into sdk package
from inductiva.machines_catalogue_client.models.available_machine_series import AvailableMachineSeries
from inductiva.machines_catalogue_client.models.available_simulator_versions import AvailableSimulatorVersions
from inductiva.machines_catalogue_client.models.available_zones import AvailableZones
from inductiva.machines_catalogue_client.models.cloud_location import CloudLocation
from inductiva.machines_catalogue_client.models.http_validation_error import HTTPValidationError
from inductiva.machines_catalogue_client.models.machine_filter_options import MachineFilterOptions
from inductiva.machines_catalogue_client.models.machine_type import MachineType
from inductiva.machines_catalogue_client.models.machine_type_with_spot_price import MachineTypeWithSpotPrice
from inductiva.machines_catalogue_client.models.preemption_stats import PreemptionStats
from inductiva.machines_catalogue_client.models.processor_type import ProcessorType
from inductiva.machines_catalogue_client.models.product_price import ProductPrice
from inductiva.machines_catalogue_client.models.providers import Providers
from inductiva.machines_catalogue_client.models.simulator_prod_update import SimulatorProdUpdate
from inductiva.machines_catalogue_client.models.simulator_response import SimulatorResponse
from inductiva.machines_catalogue_client.models.simulator_version import SimulatorVersion
from inductiva.machines_catalogue_client.models.simulator_with_machine_types_paginated import SimulatorWithMachineTypesPaginated
from inductiva.machines_catalogue_client.models.spot import Spot
from inductiva.machines_catalogue_client.models.validation_error import ValidationError
from inductiva.machines_catalogue_client.models.validation_error_loc_inner import ValidationErrorLocInner
from inductiva.machines_catalogue_client.models.validation_result import ValidationResult
from inductiva.machines_catalogue_client.models.weekly_preemption_stats import WeeklyPreemptionStats
